# resources imports
# from resources.config import CSS, JS
# from resources.utils import register_resource
# from resources.models import MergedResource
# 
# register_resource(path="/lfc/lightbox/css/jquery.lightbox-0.5.css", type=CSS)
# register_resource(path="/lfc/yui/reset-fonts.css", type=CSS)
# register_resource(path="/lfc/blueprint/src/grid.css", type=CSS)
# register_resource(path="/lfc_theme/css/tiny.css", type=CSS)
# register_resource(path="/lfc_theme/css/lfc.css", type=CSS)
# 
# register_resource(path="/lfc/jquery/jquery.min.js", type=JS)
# register_resource(path="/lfc/jquery/jquery.tools.min.js", type=JS)
# register_resource(path="/lfc/lightbox/js/jquery.lightbox-0.5.js", type=JS)
# register_resource(path="/lfc_theme/js/lfctheme.js", type=JS)
